@@ -1,6 +1,6 @@
 ctree_plots <- c(
-  "None" = "none", "Prune" = "prune", 
-  "Tree" = "tree", 
+  "None" = "none", "Prune" = "prune",
+  "Tree" = "tree",
   "Importance" = "imp",
   "Partial Dependence" = "pdp",
   "Dashboard" = "dashboard"
@@ -14,8 +14,9 @@ crtree_inputs <- reactive({
   ## loop needed because reactive values don't allow single bracket indexing
   crtree_args$data_filter <- if (input$show_filter) input$data_filter else ""
   crtree_args$dataset <- input$dataset
-  for (i in r_drop(names(crtree_args)))
+  for (i in r_drop(names(crtree_args))) {
     crtree_args[[i]] <- input[[paste0("crtree_", i)]]
+  }
   crtree_args
 })
 
@@ -28,8 +29,9 @@ crtree_pred_args <- as.list(if (exists("predict.crtree")) {
 # list of function inputs selected by user
 crtree_pred_inputs <- reactive({
   # loop needed because reactive values don't allow single bracket indexing
-  for (i in names(crtree_pred_args))
+  for (i in names(crtree_pred_args)) {
     crtree_pred_args[[i]] <- input[[paste0("crtree_", i)]]
+  }
 
   crtree_pred_args$pred_cmd <- crtree_pred_args$pred_data <- ""
   if (input$crtree_predict == "cmd") {
@@ -56,8 +58,9 @@ crtree_pred_plot_args <- as.list(if (exists("plot.model.predict")) {
 # list of function inputs selected by user
 crtree_pred_plot_inputs <- reactive({
   # loop needed because reactive values don't allow single bracket indexing
-  for (i in names(crtree_pred_plot_args))
+  for (i in names(crtree_pred_plot_args)) {
     crtree_pred_plot_args[[i]] <- input[[paste0("crtree_", i)]]
+  }
   crtree_pred_plot_args
 })
 
@@ -133,7 +136,7 @@ observeEvent(input$dataset, {
 })
 
 observeEvent(input$crtree_cost, {
-  if (!is_empty(input$crtree_cost)) {
+  if (!radiant.data::is_empty(input$crtree_cost)) {
     updateNumericInput(session = session, inputId = "crtree_prior", value = NA)
   }
 })
@@ -143,7 +146,7 @@ output$ui_crtree_predict_plot <- renderUI({
 })
 
 output$ui_crtree_width <- renderUI({
-  init <- ifelse(is_empty(input$get_screen_width), 900, (input$get_screen_width - 400))
+  init <- ifelse(radiant.data::is_empty(input$get_screen_width), 900, (input$get_screen_width - 400))
   init <- init - init %% 100
   numericInput(
     "crtree_width",
@@ -175,9 +178,10 @@ run_refresh(crtree_args, "crtree", tabs = "tabs_crtree", label = "Estimate model
 output$ui_crtree <- renderUI({
   req(input$dataset)
   tagList(
-    conditionalPanel(condition = "input.tabs_crtree == 'Summary'",
+    conditionalPanel(
+      condition = "input.tabs_crtree == 'Summary'",
       wellPanel(
-        actionButton("crtree_run", "Estimate model", width = "100%", icon = icon("play"), class = "btn-success")
+        actionButton("crtree_run", "Estimate model", width = "100%", icon = icon("play", verify_fa = FALSE), class = "btn-success")
       )
     ),
     wellPanel(
@@ -255,7 +259,7 @@ output$ui_crtree <- renderUI({
           condition = "input.tabs_crtree == 'Summary'",
           tags$table(
             tags$td(uiOutput("ui_crtree_store_res_name")),
-            tags$td(actionButton("crtree_store_res", "Store", icon = icon("plus")), style = "padding-top:30px;")
+            tags$td(actionButton("crtree_store_res", "Store", icon = icon("plus", verify_fa = FALSE)), class = "top")
           )
         )
       ),
@@ -297,7 +301,7 @@ output$ui_crtree <- renderUI({
           "input.crtree_predict == 'data' | input.crtree_predict == 'datacmd'",
           tags$table(
             tags$td(textInput("crtree_store_pred_name", "Store predictions:", state_init("crtree_store_pred_name", "pred_crtree"))),
-            tags$td(actionButton("crtree_store_pred", "Store", icon("plus")), style = "padding-top:30px;")
+            tags$td(actionButton("crtree_store_pred", "Store", icon("plus", verify_fa = FALSE)), class = "top")
           )
         )
       ),
@@ -322,7 +326,7 @@ output$ui_crtree <- renderUI({
                 c("Left-right" = "LR", "Top-down" = "TD", "Right-left" = "RL", "Bottom-Top" = "BT"),
                 state_init("crtree_orient", "LR"), width = "116px"
               ),
-              style = "padding-top:15px;"
+              style = "padding-top:16.5px;"
             ),
             tags$td(uiOutput("ui_crtree_width"), width = "100%")
           )
@@ -338,15 +342,19 @@ output$ui_crtree <- renderUI({
 })
 
 crtree_plot <- reactive({
-  if (crtree_available() != "available") return()
-  if (is_empty(input$crtree_plots, "none")) return()
+  if (crtree_available() != "available") {
+    return()
+  }
+  if (radiant.data::is_empty(input$crtree_plots, "none")) {
+    return()
+  }
   res <- .crtree()
   # if (is.character(res)) return()
   nr_vars <- length(res$evar)
   if ("dashboard" %in% input$crtree_plots) {
     plot_height <- 750
   } else if ("pdp" %in% input$crtree_plots) {
-    plot_height <- max(500, ceiling(nr_vars/2) * 250)
+    plot_height <- max(500, ceiling(nr_vars / 2) * 250)
   } else if ("vimp" %in% input$crtree_plots) {
     plot_height <- max(300, nr_vars * 50)
   } else {
@@ -356,14 +364,23 @@ crtree_plot <- reactive({
   list(plot_width = 650, plot_height = plot_height)
 })
 
-crtree_plot_width <- function()
-  crtree_plot() %>% {if (is.list(.)) .$plot_width else 650}
+crtree_plot_width <- function() {
+  crtree_plot() %>%
+    {
+      if (is.list(.)) .$plot_width else 650
+    }
+}
 
-crtree_plot_height <- function()
-  crtree_plot() %>% {if (is.list(.)) .$plot_height else 500}
+crtree_plot_height <- function() {
+  crtree_plot() %>%
+    {
+      if (is.list(.)) .$plot_height else 500
+    }
+}
 
-crtree_pred_plot_height <- function()
+crtree_pred_plot_height <- function() {
   if (input$crtree_pred_plot) 500 else 0
+}
 
 output$diagrammer_crtree <- renderUI({
   DiagrammeR::DiagrammeROutput(
@@ -402,7 +419,7 @@ output$crtree <- renderUI({
       "Plot",
       conditionalPanel(
         "input.crtree_plots == 'tree'",
-        actionLink("crtree_save_plot", "", class = "fa fa-download alignright", onclick = "window.print();"),
+        HTML("<i title='Save plot' class='fa fa-download action-button shiny-bound-input alignright' href='#crtree_screenshot2' id='crtree_screenshot2' onclick='generate_crtree_plot();'></i>"),
         uiOutput("diagrammer_crtree")
       ),
       conditionalPanel(
@@ -462,17 +479,22 @@ crtree_available <- reactive({
 })
 
 .predict_crtree <- reactive({
-  if (not_pressed(input$crtree_run)) return("** Press the Estimate button to estimate the model **")
-  if (crtree_available() != "available") return(crtree_available())
-  if (is_empty(input$crtree_predict, "none")) return("** Select prediction input **")
+  if (not_pressed(input$crtree_run)) {
+    return("** Press the Estimate button to estimate the model **")
+  }
+  if (crtree_available() != "available") {
+    return(crtree_available())
+  }
+  if (radiant.data::is_empty(input$crtree_predict, "none")) {
+    return("** Select prediction input **")
+  }
 
   if ((input$crtree_predict == "data" || input$crtree_predict == "datacmd") &&
-    is_empty(input$crtree_pred_data)) {
+    radiant.data::is_empty(input$crtree_pred_data)) {
     "** Select data for prediction **"
-  } else if (input$crtree_predict == "cmd" && is_empty(input$crtree_pred_cmd)) {
+  } else if (input$crtree_predict == "cmd" && radiant.data::is_empty(input$crtree_pred_cmd)) {
     "** Enter prediction commands **"
   } else {
-
     withProgress(message = "Generating predictions", value = 1, {
       cri <- crtree_pred_inputs()
       cri$object <- .crtree()
@@ -491,7 +513,7 @@ crtree_available <- reactive({
   req(
     pressed(input$crtree_run), input$crtree_pred_plot,
     available(input$crtree_xvar),
-    !is_empty(input$crtree_predict, "none")
+    !radiant.data::is_empty(input$crtree_predict, "none")
   )
 
   withProgress(message = "Generating prediction plot", value = 1, {
@@ -504,7 +526,7 @@ crtree_available <- reactive({
     "** Press the Estimate button to estimate the model **"
   } else if (crtree_available() != "available") {
     crtree_available()
-  } else if (is_empty(input$crtree_plots)) {
+  } else if (radiant.data::is_empty(input$crtree_plots)) {
     "Please select a plot type from the drop-down menu"
   } else {
     ret <- .crtree()
@@ -523,7 +545,9 @@ crtree_available <- reactive({
 observeEvent(input$crtree_store_res, {
   req(pressed(input$crtree_run))
   robj <- .crtree()
-  if (!is.list(robj)) return()
+  if (!is.list(robj)) {
+    return()
+  }
   fixed <- fix_names(input$crtree_store_res_name)
   updateTextInput(session, "crtree_store_res_name", value = fixed)
   withProgress(
@@ -533,9 +557,11 @@ observeEvent(input$crtree_store_res, {
 })
 
 observeEvent(input$crtree_store_pred, {
-  req(!is_empty(input$crtree_pred_data), pressed(input$crtree_run))
+  req(!radiant.data::is_empty(input$crtree_pred_data), pressed(input$crtree_run))
   pred <- .predict_crtree()
-  if (is.null(pred)) return()
+  if (is.null(pred)) {
+    return()
+  }
   fixed <- fix_names(input$crtree_store_pred_name)
   updateTextInput(session, "crtree_store_pred_name", value = fixed)
   withProgress(
@@ -547,14 +573,16 @@ observeEvent(input$crtree_store_pred, {
   )
 })
 
-observeEvent(input$crtree_report, {
-  if (is_empty(input$crtree_evar)) return(invisible())
+crtree_report <- function() {
+  if (radiant.data::is_empty(input$crtree_evar)) {
+    return(invisible())
+  }
 
   outputs <- c("summary")
   inp_out <- list(list(prn = TRUE), "")
   figs <- FALSE
 
-  if (!is_empty(input$crtree_store_res_name)) {
+  if (!radiant.data::is_empty(input$crtree_store_res_name)) {
     fixed <- fix_names(input$crtree_store_res_name)
     updateTextInput(session, "crtree_store_res_name", value = fixed)
     xcmd <- paste0(input$dataset, " <- store(", input$dataset, ", result, name = \"", fixed, "\")\n")
@@ -562,17 +590,17 @@ observeEvent(input$crtree_report, {
     xcmd <- ""
   }
 
-  if (!is_empty(input$crtree_predict, "none") &&
-    (!is_empty(input$crtree_pred_data) || !is_empty(input$crtree_pred_cmd))) {
+  if (!radiant.data::is_empty(input$crtree_predict, "none") &&
+    (!radiant.data::is_empty(input$crtree_pred_data) || !radiant.data::is_empty(input$crtree_pred_cmd))) {
     pred_args <- clean_args(crtree_pred_inputs(), crtree_pred_args[-1])
 
-    if (!is_empty(pred_args$pred_cmd)) {
+    if (!radiant.data::is_empty(pred_args$pred_cmd)) {
       pred_args$pred_cmd <- strsplit(pred_args$pred_cmd, ";")[[1]]
     } else {
       pred_args$pred_cmd <- NULL
     }
 
-    if (!is_empty(pred_args$pred_data)) {
+    if (!radiant.data::is_empty(pred_args$pred_data)) {
       pred_args$pred_data <- as.symbol(pred_args$pred_data)
     } else {
       pred_args$pred_data <- NULL
@@ -590,7 +618,7 @@ observeEvent(input$crtree_report, {
       )
     }
 
-    if (input$crtree_pred_plot && !is_empty(input$crtree_xvar)) {
+    if (input$crtree_pred_plot && !radiant.data::is_empty(input$crtree_xvar)) {
       inp_out[[3 + figs]] <- clean_args(crtree_pred_plot_inputs(), crtree_pred_plot_args[-1])
       inp_out[[3 + figs]]$result <- "pred"
       outputs <- c(outputs, "plot")
@@ -599,8 +627,8 @@ observeEvent(input$crtree_report, {
   }
 
   if (input$crtree_plots != "none") {
-    width <- ifelse(is_empty(input$crtree_width), "\"900px\"", paste0("\"", input$crtree_width, "px\""))
-    orient <- ifelse(is_empty(input$crtree_orient), "\"TD\"", paste0("\"", input$crtree_orient, "\""))
+    width <- ifelse(radiant.data::is_empty(input$crtree_width), "\"900px\"", paste0("\"", input$crtree_width, "px\""))
+    orient <- ifelse(radiant.data::is_empty(input$crtree_orient), "\"TD\"", paste0("\"", input$crtree_orient, "\""))
     if (input$crtree_plots == "tree") {
       xcmd <- paste0(xcmd, "\n# plot(result, plots = \"prune\", custom = FALSE)")
       xcmd <- paste0(xcmd, "\nplot(result, orient = ", orient, ", width = ", width, ") %>% render()")
@@ -630,7 +658,7 @@ observeEvent(input$crtree_report, {
     fig.height = crtree_plot_height(),
     xcmd = xcmd
   )
-})
+}
 
 dl_crtree_pred <- function(path) {
   if (pressed(input$crtree_run)) {
@@ -669,3 +697,28 @@ download_handler(
   width = crtree_plot_width,
   height = crtree_plot_height
 )
+
+observeEvent(input$crtree_report, {
+  r_info[["latest_screenshot"]] <- NULL
+  crtree_report()
+})
+
+observeEvent(input$crtree_screenshot, {
+  r_info[["latest_screenshot"]] <- NULL
+  radiant_screenshot_modal("modal_crtree_screenshot")
+})
+
+observeEvent(input$modal_crtree_screenshot, {
+  crtree_report()
+  removeModal() ## remove shiny modal after save
+})
+
+observeEvent(input$crtree_screenshot2, {
+  r_info[["latest_screenshot"]] <- NULL
+  radiant_screenshot_modal("modal_crtree_screenshot2")
+})
+
+observeEvent(input$modal_crtree_screenshot2, {
+  crtree_report()
+  removeModal() ## remove shiny modal after save
+})
\ No newline at end of file
