@@ -12,8 +12,9 @@ nb_inputs <- reactive({
   ## loop needed because reactive values don't allow single bracket indexing
   nb_args$data_filter <- if (input$show_filter) input$data_filter else ""
   nb_args$dataset <- input$dataset
-  for (i in r_drop(names(nb_args)))
+  for (i in r_drop(names(nb_args))) {
     nb_args[[i]] <- input[[paste0("nb_", i)]]
+  }
   nb_args
 })
 
@@ -21,13 +22,14 @@ nb_plot_args <- as.list(if (exists("plot.nb")) {
   formals(plot.nb)
 } else {
   formals(radiant.model:::plot.nb)
-} )
+})
 
 ## list of function inputs selected by user
 nb_plot_inputs <- reactive({
   ## loop needed because reactive values don't allow single bracket indexing
-  for (i in names(nb_plot_args))
+  for (i in names(nb_plot_args)) {
     nb_plot_args[[i]] <- input[[paste0("nb_", i)]]
+  }
   nb_plot_args
 })
 
@@ -35,13 +37,14 @@ nb_pred_args <- as.list(if (exists("predict.nb")) {
   formals(predict.nb)
 } else {
   formals(radiant.model:::predict.nb)
-} )
+})
 
 ## list of function inputs selected by user
 nb_pred_inputs <- reactive({
   ## loop needed because reactive values don't allow single bracket indexing
-  for (i in names(nb_pred_args))
+  for (i in names(nb_pred_args)) {
     nb_pred_args[[i]] <- input[[paste0("nb_", i)]]
+  }
 
   nb_pred_args$pred_cmd <- nb_pred_args$pred_data <- ""
   if (input$nb_predict == "cmd") {
@@ -68,8 +71,9 @@ nb_pred_plot_args <- as.list(if (exists("plot.model.predict")) {
 ## list of function inputs selected by user
 nb_pred_plot_inputs <- reactive({
   ## loop needed because reactive values don't allow single bracket indexing
-  for (i in names(nb_pred_plot_args))
+  for (i in names(nb_pred_plot_args)) {
     nb_pred_plot_args[[i]] <- input[[paste0("nb_", i)]]
+  }
   nb_pred_plot_args
 })
 
@@ -79,7 +83,7 @@ output$ui_nb_rvar <- renderUI({
     vars <- varnames()[isFct]
   })
 
-  init <- if (is_empty(input$logit_rvar)) isolate(input$nb_rvar) else input$logit_rvar
+  init <- if (radiant.data::is_empty(input$logit_rvar)) isolate(input$nb_rvar) else input$logit_rvar
   selectInput(
     inputId = "nb_rvar", label = "Response variable:", choices = vars,
     selected = state_single("nb_rvar", vars, init), multiple = FALSE
@@ -108,7 +112,7 @@ output$ui_nb_evar <- renderUI({
   }
 
   ## initialize to variables selected for logistic regression
-  init <- if (is_empty(input$logit_evar)) isolate(input$nb_evar) else input$logit_evar
+  init <- if (radiant.data::is_empty(input$logit_evar)) isolate(input$nb_evar) else input$logit_evar
   selectInput(
     inputId = "nb_evar", label = "Explanatory variables:",
     choices = vars,
@@ -150,9 +154,10 @@ run_refresh(nb_args, "nb", tabs = "tabs_nb", label = "Estimate model", relabel =
 output$ui_nb <- renderUI({
   req(input$dataset)
   tagList(
-    conditionalPanel(condition = "input.tabs_nb == 'Summary'",
+    conditionalPanel(
+      condition = "input.tabs_nb == 'Summary'",
       wellPanel(
-        actionButton("nb_run", "Estimate model", width = "100%", icon = icon("play"), class = "btn-success")
+        actionButton("nb_run", "Estimate model", width = "100%", icon = icon("play", verify_fa = FALSE), class = "btn-success")
       )
     ),
     wellPanel(
@@ -165,7 +170,8 @@ output$ui_nb <- renderUI({
       conditionalPanel(
         condition = "input.tabs_nb == 'Predict'",
         selectInput(
-          "nb_predict", label = "Prediction input type:", reg_predict,
+          "nb_predict",
+          label = "Prediction input type:", reg_predict,
           selected = state_single("nb_predict", reg_predict, "none")
         ),
         conditionalPanel(
@@ -199,14 +205,15 @@ output$ui_nb <- renderUI({
           "input.nb_predict == 'data' | input.nb_predict == 'datacmd'",
           tags$table(
             tags$td(uiOutput("ui_nb_store_pred_name")),
-            tags$td(actionButton("nb_store_pred", "Store", icon = icon("plus")), style = "padding-top:30px;")
+            tags$td(actionButton("nb_store_pred", "Store", icon = icon("plus", verify_fa = FALSE)), class = "top")
           )
         )
       ),
       conditionalPanel(
         condition = "input.tabs_nb == 'Plot'",
         selectInput(
-          "nb_plots", "Plots:", choices = nb_plots,
+          "nb_plots", "Plots:",
+          choices = nb_plots,
           selected = state_single("nb_plots", nb_plots)
         ),
         conditionalPanel(
@@ -224,12 +231,18 @@ output$ui_nb <- renderUI({
 })
 
 nb_plot <- reactive({
-  if (nb_available() != "available") return()
-  if (is_empty(input$nb_plots, "none")) return()
+  if (nb_available() != "available") {
+    return()
+  }
+  if (radiant.data::is_empty(input$nb_plots, "none")) {
+    return()
+  }
   req(input$nb_lev)
 
   nb_res <- .nb()
-  if (is.character(nb_res)) return()
+  if (is.character(nb_res)) {
+    return()
+  }
 
   n_vars <- length(nb_res$vars)
   if (input$nb_plots == "correlations") {
@@ -247,14 +260,23 @@ nb_plot <- reactive({
   list(plot_width = plot_width, plot_height = plot_height)
 })
 
-nb_plot_width <- function()
-  nb_plot() %>% {if (is.list(.)) .$plot_width else 650}
+nb_plot_width <- function() {
+  nb_plot() %>%
+    {
+      if (is.list(.)) .$plot_width else 650
+    }
+}
 
-nb_plot_height <- function()
-  nb_plot() %>% {if (is.list(.)) .$plot_height else 500}
+nb_plot_height <- function() {
+  nb_plot() %>%
+    {
+      if (is.list(.)) .$plot_height else 500
+    }
+}
 
-nb_pred_plot_height <- function()
+nb_pred_plot_height <- function() {
   if (input$nb_pred_plot) 500 else 1
+}
 
 ## output is called from the main radiant ui.R
 output$nb <- renderUI({
@@ -314,25 +336,34 @@ nb_available <- reactive({
     nbi <- nb_inputs()
     nbi$envir <- r_data
     do.call(nb, nbi)
-
   })
 })
 
 .summary_nb <- reactive({
-  if (not_pressed(input$nb_run)) return("** Press the Estimate button to estimate the model **")
-  if (nb_available() != "available") return(nb_available())
+  if (not_pressed(input$nb_run)) {
+    return("** Press the Estimate button to estimate the model **")
+  }
+  if (nb_available() != "available") {
+    return(nb_available())
+  }
   summary(.nb())
 })
 
 .predict_nb <- reactive({
-  if (nb_available() != "available") return(nb_available())
-  if (not_pressed(input$nb_run)) return("** Press the Estimate button to estimate the model **")
-  if (is_empty(input$nb_predict, "none")) return("** Select prediction input **")
+  if (nb_available() != "available") {
+    return(nb_available())
+  }
+  if (not_pressed(input$nb_run)) {
+    return("** Press the Estimate button to estimate the model **")
+  }
+  if (radiant.data::is_empty(input$nb_predict, "none")) {
+    return("** Select prediction input **")
+  }
 
-  if ((input$nb_predict == "data" || input$nb_predict == "datacmd") && is_empty(input$nb_pred_data)) {
+  if ((input$nb_predict == "data" || input$nb_predict == "datacmd") && radiant.data::is_empty(input$nb_pred_data)) {
     return("** Select data for prediction **")
   }
-  if (input$nb_predict == "cmd" && is_empty(input$nb_pred_cmd)) {
+  if (input$nb_predict == "cmd" && radiant.data::is_empty(input$nb_pred_cmd)) {
     return("** Enter prediction commands **")
   }
 
@@ -345,27 +376,28 @@ nb_available <- reactive({
 })
 
 .predict_print_nb <- reactive({
-  .predict_nb() %>% {
-    if (is.character(.)) cat(., "\n") else print(.)
-  }
+  .predict_nb() %>%
+    {
+      if (is.character(.)) cat(., "\n") else print(.)
+    }
 })
 
 .predict_plot_nb <- reactive({
   req(
     pressed(input$nb_run), input$nb_pred_plot,
     available(input$nb_xvar),
-    !is_empty(input$nb_predict, "none")
+    !radiant.data::is_empty(input$nb_predict, "none")
   )
 
   ## needs more testing ...
   # if (nb_available() != "available") return(nb_available())
   # # req(input$nb_pred_plot, available(input$nb_xvar))
   # if (not_pressed(input$nb_run)) return(invisible())
-  # if (is_empty(input$nb_predict, "none")) return(invisible())
-  # if ((input$nb_predict == "data" || input$nb_predict == "datacmd") && is_empty(input$nb_pred_data)) {
+  # if (radiant.data::is_empty(input$nb_predict, "none")) return(invisible())
+  # if ((input$nb_predict == "data" || input$nb_predict == "datacmd") && radiant.data::is_empty(input$nb_pred_data)) {
   #   return(invisible())
   # }
-  # if (input$nb_predict == "cmd" && is_empty(input$nb_pred_cmd)) {
+  # if (input$nb_predict == "cmd" && radiant.data::is_empty(input$nb_pred_cmd)) {
   #   return(invisible())
   # }
 
@@ -377,7 +409,7 @@ nb_available <- reactive({
 .plot_nb <- reactive({
   if (not_pressed(input$nb_run)) {
     return("** Press the Estimate button to estimate the model **")
-  } else if (is_empty(input$nb_plots, "none")) {
+  } else if (radiant.data::is_empty(input$nb_plots, "none")) {
     return("Please select a naive Bayes plot from the drop-down menu")
   } else if (nb_available() != "available") {
     return(nb_available())
@@ -393,9 +425,11 @@ nb_available <- reactive({
 })
 
 observeEvent(input$nb_store_pred, {
-  req(!is_empty(input$nb_pred_data), pressed(input$nb_run))
+  req(!radiant.data::is_empty(input$nb_pred_data), pressed(input$nb_run))
   pred <- .predict_nb()
-  if (is.null(pred)) return()
+  if (is.null(pred)) {
+    return()
+  }
   fixed <- unlist(strsplit(input$nb_store_pred_name, "(\\s*,\\s*|\\s*;\\s*)")) %>%
     fix_names() %>%
     paste0(collapse = ", ")
@@ -409,28 +443,30 @@ observeEvent(input$nb_store_pred, {
   )
 })
 
-observeEvent(input$nb_report, {
-  if (is_empty(input$nb_evar)) return(invisible())
+nb_report <- function() {
+  if (radiant.data::is_empty(input$nb_evar)) {
+    return(invisible())
+  }
   outputs <- c("summary")
   inp_out <- list("", "")
   figs <- FALSE
-  if (!is_empty(input$nb_plots, "none")) {
+  if (!radiant.data::is_empty(input$nb_plots, "none")) {
     inp_out[[2]] <- clean_args(nb_plot_inputs(), nb_plot_args[-1])
     outputs <- c(outputs, "plot")
     figs <- TRUE
   }
   xcmd <- ""
-  if (!is_empty(input$nb_predict, "none") &&
-     (!is_empty(input$nb_pred_data) || !is_empty(input$nb_pred_cmd))) {
+  if (!radiant.data::is_empty(input$nb_predict, "none") &&
+    (!radiant.data::is_empty(input$nb_pred_data) || !radiant.data::is_empty(input$nb_pred_cmd))) {
     pred_args <- clean_args(nb_pred_inputs(), nb_pred_args[-1])
 
-    if (!is_empty(pred_args$pred_cmd)) {
+    if (!radiant.data::is_empty(pred_args$pred_cmd)) {
       pred_args$pred_cmd <- strsplit(pred_args$pred_cmd, ";")[[1]]
     } else {
       pred_args$pred_cmd <- NULL
     }
 
-    if (!is_empty(pred_args$pred_data)) {
+    if (!radiant.data::is_empty(pred_args$pred_data)) {
       pred_args$pred_data <- as.symbol(pred_args$pred_data)
     } else {
       pred_args$pred_data <- NULL
@@ -441,17 +477,18 @@ observeEvent(input$nb_report, {
     xcmd <- paste0("print(pred, n = 10)")
     if (input$nb_predict %in% c("data", "datacmd")) {
       name <- input$nb_store_pred_name
-      if (!is_empty(name)) {
+      if (!radiant.data::is_empty(name)) {
         name <- unlist(strsplit(input$nb_store_pred_name, "(\\s*,\\s*|\\s*;\\s*)")) %>%
           fix_names() %>%
           deparse(., control = getOption("dctrl"), width.cutoff = 500L)
       }
-      xcmd <- paste0(xcmd, "\n", input$nb_pred_data, " <- store(",
+      xcmd <- paste0(
+        xcmd, "\n", input$nb_pred_data, " <- store(",
         input$nb_pred_data, ", pred, name = ", name, ")"
       )
     }
 
-    if (input$nb_pred_plot && !is_empty(input$nb_xvar)) {
+    if (input$nb_pred_plot && !radiant.data::is_empty(input$nb_xvar)) {
       inp_out[[3 + figs]] <- clean_args(nb_pred_plot_inputs(), nb_pred_plot_args[-1])
       inp_out[[3 + figs]]$result <- "pred"
       outputs <- c(outputs, "plot")
@@ -469,7 +506,7 @@ observeEvent(input$nb_report, {
     fig.height = nb_plot_height(),
     xcmd = xcmd
   )
-})
+}
 
 dl_nb_pred <- function(path) {
   if (pressed(input$nb_run)) {
@@ -508,3 +545,18 @@ download_handler(
   width = nb_plot_width,
   height = nb_plot_height
 )
+
+observeEvent(input$nb_report, {
+  r_info[["latest_screenshot"]] <- NULL
+  nb_report()
+})
+
+observeEvent(input$nb_screenshot, {
+  r_info[["latest_screenshot"]] <- NULL
+  radiant_screenshot_modal("modal_nb_screenshot")
+})
+
+observeEvent(input$modal_nb_screenshot, {
+  nb_report()
+  removeModal() ## remove shiny modal after save
+})
\ No newline at end of file
